@@ -1,4 +1,4 @@
-# Copyright 2020 The TensorFlow Authors. All Rights Reserved.
+# Copyright 2022 The TensorFlow Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,7 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-# ==============================================================================
 
 import pprint
 from typing import List, Tuple
@@ -44,6 +43,17 @@ class DumpConfig3(DumpConfig2):
   g: Tuple[DumpConfig1, ...] = (DumpConfig1(),)
 
 
+@dataclasses.dataclass
+class DumpConfig4(DumpConfig2):
+  x: int = 3
+
+
+@dataclasses.dataclass
+class DummyConfig5(base_config.Config):
+  y: Tuple[DumpConfig2, ...] = (DumpConfig2(), DumpConfig4())
+  z: Tuple[str] = ('a',)
+
+
 class BaseConfigTest(parameterized.TestCase, tf.test.TestCase):
 
   def assertHasSameTypes(self, c, d, msg=''):
@@ -81,6 +91,31 @@ class BaseConfigTest(parameterized.TestCase, tf.test.TestCase):
     with self.assertRaises(AttributeError):
       _ = params.a
 
+  def test_cls(self):
+    params = base_config.Config()
+    with self.assertRaisesRegex(
+        AttributeError,
+        '`BUILDER` is a property and `_BUILDER` is the reserved'):
+      params.BUILDER = DumpConfig2
+    with self.assertRaisesRegex(
+        AttributeError,
+        '`BUILDER` is a property and `_BUILDER` is the reserved'):
+      params._BUILDER = DumpConfig2
+
+    base_config.bind(DumpConfig1)(DumpConfig2)
+    params = DumpConfig1()
+    self.assertEqual(params.BUILDER, DumpConfig2)
+    with self.assertRaisesRegex(ValueError,
+                                'Inside a program, we should not bind'):
+      base_config.bind(DumpConfig1)(DumpConfig2)
+
+    def _test():
+      return 'test'
+
+    base_config.bind(DumpConfig2)(_test)
+    params = DumpConfig2()
+    self.assertEqual(params.BUILDER(), 'test')
+
   def test_nested_config_types(self):
     config = DumpConfig3()
     self.assertIsInstance(config.e, DumpConfig1)
@@ -162,10 +197,8 @@ class BaseConfigTest(parameterized.TestCase, tf.test.TestCase):
       params.override({'c': {'c3': 30}}, is_strict=True)
 
     config = base_config.Config({'key': [{'a': 42}]})
-    config.override({'key': [{'b': 43}]})
-    self.assertEqual(config.key[0].b, 43)
-    with self.assertRaisesRegex(AttributeError, 'The key `a` does not exist'):
-      _ = config.key[0].a
+    with self.assertRaisesRegex(KeyError, "The key 'b' does not exist"):
+      config.override({'key': [{'b': 43}]})
 
   @parameterized.parameters(
       (lambda x: x, 'Unknown type'),
@@ -314,6 +347,39 @@ class BaseConfigTest(parameterized.TestCase, tf.test.TestCase):
     config = DumpConfig2(restrictions=restrictions)
     config.validate()
 
+  def test_nested_tuple(self):
+    config = DummyConfig5()
+    config.override({
+        'y': [{
+            'c': 4,
+            'd': 'new text 3',
+            'e': {
+                'a': 2
+            }
+        }, {
+            'c': 0,
+            'd': 'new text 3',
+            'e': {
+                'a': 2
+            }
+        }],
+        'z': ['a', 'b', 'c'],
+    })
+    self.assertEqual(config.y[0].c, 4)
+    self.assertEqual(config.y[1].c, 0)
+    self.assertIsInstance(config.y[0], DumpConfig2)
+    self.assertIsInstance(config.y[1], DumpConfig4)
+    self.assertSameElements(config.z, ['a', 'b', 'c'])
+
+  def test_override_by_empty_sequence(self):
+    config = DummyConfig5()
+    config.override({
+        'y': [],
+        'z': (),
+    }, is_strict=True)
+    self.assertEmpty(config.y)
+    self.assertEmpty(config.z)
+
 
 if __name__ == '__main__':
   tf.test.main()
