@@ -1,4 +1,4 @@
-# Copyright 2021 The TensorFlow Authors. All Rights Reserved.
+# Copyright 2022 The TensorFlow Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,7 +28,7 @@ from absl import logging
 import numpy as np
 import tensorflow as tf
 
-from official.nlp.bert import tokenization
+from official.nlp.tools import tokenization
 
 
 class SquadExample(object):
@@ -175,7 +175,7 @@ def _convert_index(index, pos, m=None, is_start=True):
     front -= 1
   assert index[front] is not None or index[rear] is not None
   if index[front] is None:
-    if index[rear] >= 1:
+    if index[rear] >= 1:  # pytype: disable=unsupported-operands
       if is_start:
         return 0
       else:
