@@ -1,4 +1,4 @@
-# Copyright 2021 The TensorFlow Authors. All Rights Reserved.
+# Copyright 2022 The TensorFlow Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,5 +13,8 @@
 # limitations under the License.
 
 """TensorFlow Models NLP Libraries."""
+
 from official.nlp import tasks
+from official.nlp.configs import encoders
 from official.nlp.modeling import *
+from official.nlp.serving import serving_modules
